# IndividualDisplacements.jl

[![Travis Build Status](https://travis-ci.org/JuliaClimate/IndividualDisplacements.jl.svg?branch=master)](https://travis-ci.org/JuliaClimate/IndividualDisplacements.jl)
[![](https://img.shields.io/badge/docs-stable-blue.svg)](https://JuliaClimate.github.io/IndividualDisplacements.jl/stable)
[![](https://img.shields.io/badge/docs-dev-blue.svg)](https://JuliaClimate.github.io/IndividualDisplacements.jl/dev)
[![codecov](https://codecov.io/gh/JuliaClimate/IndividualDisplacements.jl/branch/master/graph/badge.svg?token=qgMClXyzVB)](https://codecov.io/gh/JuliaClimate/IndividualDisplacements.jl)

[![DOI](https://zenodo.org/badge/208676176.svg)](https://zenodo.org/badge/latestdoi/208676176)
[![](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/JuliaClimate/IndividualDisplacements.jl/web1?filepath=docs%2Fsrc%2Fnotebooks)

**IndividualDisplacements.jl** computes point displacements over a gridded domain. It is geared towards the analysis of Climate, Ocean, etc models (`Arakawa C-grids` are natively supported) and the simulation of material transports within the Earth System (e.g. plastics or planktons in the Ocean; dusts or chemicals in the Atmosphere). 


[<img src="https://user-images.githubusercontent.com/20276764/90925145-ca90cc80-e3be-11ea-8eed-559307dcb925.png" width="40%">](https://youtu.be/tsdf4fmYt1k)
[<img src="https://user-images.githubusercontent.com/20276764/90924860-41799580-e3be-11ea-96bd-9a5784d00ecc.png" width="40%">](https://youtu.be/82HPnYBtoVo)

Inter-operability with popular climate model grids via [MeshArrays.jl](https://github.com/JuliaClimate/MeshArrays.jl) is an important aspect. The package can read and write individual displacement collection files, including those generated by the [MIT general circulation model](https://mitgcm.readthedocs.io/en/latest/?badge=latest). `IndividualDisplacements`'s initial test suite is based on global ocean model simulations called [ECCO (v4r2)](https://eccov4.readthedocs.io/en/latest/) and [CBIOMES (alpha)](https://cbiomes.readthedocs.io/en/latest/) (see [Forget et al. 2015](https://doi.org/10.5194/gmd-8-3071-2015)).

### Installation

```
using Pkg
Pkg.add("IndividualDisplacements")
Pkg.test("IndividualDisplacements")
```

### Examples

The movies highlighted above are from [global\_ocean\_circulation.jl](https://juliaclimate.github.io/IndividualDisplacements.jl/dev/worldwide/global_ocean_circulation/). The basic examples shown below are from [solid\_body\_rotation.jl](https://juliaclimate.github.io/IndividualDisplacements.jl/dev/basics/solid_body_rotation/) and [random\_flow\_field.jl](https://juliaclimate.github.io/IndividualDisplacements.jl/dev/basics/random_flow_field/). For more, please report to [the docs](https://JuliaClimate.github.io/IndividualDisplacements.jl/dev).


<img src="https://github.com/JuliaClimate/IndividualDisplacements.jl/raw/master/examples/figs/SolidBodyRotation.png" width="40%">  <img src="https://github.com/JuliaClimate/IndividualDisplacements.jl/raw/master/examples/figs/RandomFlow.gif" width="40%">
